==> SugarCE-5.5.1.zip: SugarCE-Full-5.5.1/modules/ProjectTask/Dashlets/MyProjectTaskDashlet/MyProjectTaskDashlet.data.php <==
<?php
if(!defined('sugarEntry') || !sugarEntry) die('Not A Valid Entry Point');
/*********************************************************************************
 * SugarCRM is a customer relationship management program developed by
 * SugarCRM, Inc. Copyright (C) 2004-2010 SugarCRM Inc.
 * 
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License version 3 as published by the
 * Free Software Foundation with the addition of the following permission added
 * to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED WORK
 * IN WHICH THE COPYRIGHT IS OWNED BY SUGARCRM, SUGARCRM DISCLAIMS THE WARRANTY
 * OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, see http://www.gnu.org/licenses or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301 USA.
 * 
 * You can contact SugarCRM, Inc. headquarters at 10050 North Wolfe Road,
 * SW2-130, Cupertino, CA 95014, USA. or at email address contact@sugarcrm.com.
 * 
 * The interactive user interfaces in modified source and object code versions
 * of this program must display Appropriate Legal Notices, as required under
 * Section 5 of the GNU General Public License version 3.
 * 
 * In accordance with Section 7(b) of the GNU General Public License version 3,
 * these Appropriate Legal Notices must retain the display of the "Powered by
 * SugarCRM" logo. If the display of the logo is not reasonably feasible for
 * technical reasons, the Appropriate Legal Notices must display the words
 * "Powered by SugarCRM".
 ********************************************************************************/



global $current_user;

$dashletData['MyProjectTaskDashlet']['searchFields'] =  array(
                                                            'date_entered'     => array('default' => ''),                                    
                                                            'date_start'        => array('default' => ''),
                                                            'date_finish'         => array('default' => ''),
                                                            'assigned_user_id' => array('type'    => 'assigned_user_name', 
                                                                                        'default' => $current_user->name),
                                                            );
$dashletData['MyProjectTaskDashlet']['columns'] = array('name' => array('width'   => '40', 
                                                                       'label'   => 'LBL_NAME',
                                                                       'link'    => true,
                                                                       'default' => true), 
                                                       'priority' => array('width'   => '20',
                                                                           'label'   => 'LBL_PRIORITY',
                                                                          ),
                                                       'date_finish' => array('width'   => '20',
                                                                           'label'   => 'LBL_DATE_FINISH',
                                                                           'default' => true),
                                                       'time_finish' => array('width' => '15',
                                                                           'label' => 'LBL_TIME_FINISH'),
                                                       'date_start' => array('width' => '15',
                                                                             'label' => 'LBL_DATE_START',
                                                                             'default' => true),
                                                       'time_start' => array('width' => '15',
                                                                             'label' => 'LBL_TIME_START'),
                                                       'percent_complete' => array('width' => '15',
                                                                             'label' => 'LBL_PERCENT_COMPLETE'),
                                                       'project_name' => array('width' => '30',
                                                                              'label' => 'LBL_PROJECT_NAME',
                                                                              'related_fields' => array('project_id')),
                                                       'milestone_flag' => array('width' => '10',
                                                                                 'label' => 'LBL_MILESTONE_FLAG'),
                                                       'date_entered' => array('width' => '15', 
                                                                               'label' => 'LBL_DATE_ENTERED',
                                                                               'default' => true),
                                                       'date_modified' => array('width' => '15', 
                                                                                'label' => 'LBL_DATE_MODIFIED'),    
                                                       'created_by' => array('width' => '8', 
                                                                             'label' => 'LBL_CREATED'),
                                                       'assigned_user_name' => array('width'   => '8', 
                                                                                     'label'   => 'LBL_LIST_ASSIGNED_USER',
                                                                                     'default' => true),
                                                                           );

?>

==> SugarCE-6.1.4.zip: SugarCE-Full-6.1.4/modules/ProjectTask/Dashlets/MyProjectTaskDashlet/MyProjectTaskDashlet.data.php <==
<?php
if(!defined('sugarEntry') || !sugarEntry) die('Not A Valid Entry Point');
/*********************************************************************************
 * SugarCRM is a customer relationship management program developed by
 * SugarCRM, Inc. Copyright (C) 2004-2011 SugarCRM Inc.
 * 
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License version 3 as published by the
 * Free Software Foundation with the addition of the following permission added
 * to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED WORK
 * IN WHICH THE COPYRIGHT IS OWNED BY SUGARCRM, SUGARCRM DISCLAIMS THE WARRANTY
 * OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU Affero General Public License along with
 * this program; if not, see http://www.gnu.org/licenses or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301 USA.
 * 
 * You can contact SugarCRM, Inc. headquarters at 10050 North Wolfe Road,
 * SW2-130, Cupertino, CA 95014, USA. or at email address contact@sugarcrm.com.
 * 
 * The interactive user interfaces in modified source and object code versions
 * of this program must display Appropriate Legal Notices, as required under
 * Section 5 of the GNU Affero General Public License version 3.
 * 
 * In accordance with Section 7(b) of the GNU Affero General Public License version 3,
 * these Appropriate Legal Notices must retain the display of the "Powered by
 * SugarCRM" logo. If the display of the logo is not reasonably feasible for
 * technical reasons, the Appropriate Legal Notices must display the words
 * "Powered by SugarCRM".
 ********************************************************************************/




global $current_user;

$dashletData['MyProjectTaskDashlet']['searchFields'] =  array(
                                                            'date_entered'     => array('default' => ''), 
															'priority'	     => array('default' => ''),                              
                                                            'date_start'        => array('default' => ''),
                                                            'date_finish'         => array('default' => ''),
															'assigned_user_id' => array('type'    => 'assigned_user_name',
																						'label'   => 'LBL_ASSIGNED_TO', 
                                                                                        'default' => $current_user->name),

                                                            );
$dashletData['MyProjectTaskDashlet']['columns'] = array('name' => array('width'   => '45', 
                                                                       'label'   => 'LBL_NAME',
                                                                       'link'    => true,
                                                                       'default' => true), 
                                                       'priority' => array('width'   => '15',
                                                                           'label'   => 'LBL_PRIORITY',
																		   'default' => true,
                                                                          ),
                                                       'date_start' => array('width' => '15',
                                                                             'label' => 'LBL_DATE_START',
                                                                             'default' => true),
                                                       'time_start' => array('width' => '15',
                                                                             'label' => 'LBL_TIME_START'),
                                                       'date_finish' => array('width'   => '15',
                                                                           'label'   => 'LBL_DATE_FINISH',
                                                                           'default' => true),
                                                       'time_finish' => array('width' => '15',
                                                                           'label' => 'LBL_TIME_FINISH'),                   
                                                       'percent_complete' => array('width' => '10',
                                                                             'label' => 'LBL_PERCENT_COMPLETE',
                                                                             'default' => true),
                                                       'project_name' => array('width' => '30',
                                                                              'label' => 'LBL_PROJECT_NAME',
                                                                              'related_fields' => array('project_id')),
                                                       'milestone_flag' => array('width' => '10',
                                                                                 'label' => 'LBL_MILESTONE_FLAG'),
                                                       'date_entered' => array('width' => '15', 
                                                                               'label' => 'LBL_DATE_ENTERED'),
                                                       'date_modified' => array('width' => '15', 
                                                                                'label' => 'LBL_DATE_MODIFIED'),    
                                                       'created_by' => array('width' => '8', 
                                                                             'label' => 'LBL_CREATED'),
                                                       'assigned_user_name' => array('width'   => '8', 
                                                                                     'label'   => 'LBL_LIST_ASSIGNED_USER'),
                                                                           );

?>
